import 'dart:io';

import 'package:contacts_service/contacts_service.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test_bhargav/utils/common_utils.dart';
import 'package:flutter_test_bhargav/utils/string_utils.dart';
import 'package:flutter_test_bhargav/widgets/widgets_importer.dart';

import 'invite_contact_screen.dart';

class ContactSelection extends StatefulWidget {
  ContactSelection({Key key, this.title}) : super(key: key);

  final String title;
  final Color floatingButtonColor = Colors.red;
  final IconData reloadIcon = Icons.refresh;
  final IconData fireIcon = Icons.filter_center_focus;

  @override
  _ContactSelectionState createState() => new _ContactSelectionState();
}

class _ContactSelectionState extends State<ContactSelection> {
  List<Contact> _contacts = new List<Contact>();
  List<CustomContact> _uiCustomContacts = List<CustomContact>();
  List<CustomContact> _allContacts = List<CustomContact>();
  bool _isLoading = false;
  bool _isSelectedContactsView = false;

  @override
  void initState() {
    super.initState();
    refreshContacts();
  }

  @override
  Widget build(BuildContext context) {
    return SafeArea(
      child: new Scaffold(
        body: !_isLoading
            ? Column(
                children: <Widget>[
                  InkWell(
                    onTap: () {
                      Navigator.pop(context);
                    },
                    child: Padding(
                      padding: const EdgeInsets.all(10.0),
                      child: AddText(StringUtils.CANCLE, Colors.red, 20,
                          FontWeight.normal, false),
                    ),
                  ),
                  Row(
                    children: <Widget>[
                      AddTopButton(true),
                      AddTopButton(false),
                    ],
                  ),
                  Expanded(
                    child: ListView.builder(
                      itemCount: _uiCustomContacts?.length,
                      itemBuilder: (BuildContext context, int index) {
                        CustomContact _contact = _uiCustomContacts[index];
                        var _phonesList = _contact.contact.phones.toList();
                        return _buildListTile(_contact, _phonesList);
                      },
                    ),
                  ),
                ],
              )
            : Center(
                child: CircularProgressIndicator(),
              ),
      ),
    );
  }

  void selectAll() {
    for (int i = 0; i < _allContacts.length; i++) {
      _allContacts[i].isChecked = true;
    }
  }

  void _onSubmit() {
    setState(() {
      if (!_isSelectedContactsView) {
        _uiCustomContacts =
            _allContacts.where((contact) => contact.isChecked == true).toList();
        _isSelectedContactsView = true;
      } else {
        _uiCustomContacts = _allContacts;
        _isSelectedContactsView = false;
      }
    });
  }

  ListTile _buildListTile(CustomContact c, List<Item> list) {
    return ListTile(
      title: Text(c.contact.displayName ?? ""),
      subtitle: list.length >= 1 && list[0]?.value != null
          ? Text(list[0].value)
          : Text(''),
      trailing: Checkbox(
          activeColor: Colors.green,
          value: c.isChecked,
          onChanged: (bool value) {
            setState(() {
              c.isChecked = value;
            });
          }),
    );
  }

  refreshContacts() async {
    setState(() {
      _isLoading = true;
    });
    var contacts = await ContactsService.getContacts();
    _populateContacts(contacts);
  }

  void _populateContacts(Iterable<Contact> contacts) {
    _contacts = contacts.where((item) => item.displayName != null).toList();
    _contacts.sort((a, b) => a.displayName.compareTo(b.displayName));
    _allContacts =
        _contacts.map((contact) => CustomContact(contact: contact)).toList();
    setState(() {
      _uiCustomContacts = _allContacts;
      _isLoading = false;
    });
  }

  Widget AddTopButton(bool isSelectAll) {
    return Expanded(
      child: Align(
        alignment: isSelectAll ? Alignment.centerLeft : Alignment.centerRight,
        child: InkWell(
          onTap: () {
            if (isSelectAll) {
              setState(() {
                selectAll();
              });
            } else {
              proceed();
            }
          },
          child: Padding(
            padding: const EdgeInsets.all(15.0),
            child: AddText(
                isSelectAll ? StringUtils.SELECT_ALL : StringUtils.PROCEED_,
                isSelectAll ? Colors.black : Colors.green,
                18,
                FontWeight.normal,
                false),
          ),
        ),
      ),
    );
  }

  Future<void> proceed() async {
    try {
      final result = await InternetAddress.lookup('google.com');
      if (result.isNotEmpty && result[0].rawAddress.isNotEmpty) {
        _uiCustomContacts =
            _allContacts.where((contact) => contact.isChecked == true).toList();
        Route route = MaterialPageRoute(builder: (context) => InviteContact(_uiCustomContacts));
        Navigator.pushReplacement(context, route);
       /*Navigator.push(
          context,
          MaterialPageRoute(builder: (context) => InviteContact(_uiCustomContacts)),
        );*/
      }
    } on SocketException catch (_) {
      CommonUtils.showToast(StringUtils.CHECK_NETWORK, Colors.red);
    }
  }
}

class CustomContact {
  final Contact contact;
  bool isChecked;

  CustomContact({
    this.contact,
    this.isChecked = false,
  });
}
